==> rpp-6.1.1.tar.gz: rpp-rocm-6.1.1/src/modules/cpu/host_tensor_geometric_augmentations.hpp <==
/*
Copyright (c) 2019 - 2023 Advanced Micro Devices, Inc. All rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

#ifndef HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP
#define HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP

#include "kernel/crop.hpp"
#include "kernel/crop_mirror_normalize.hpp"
#include "kernel/flip.hpp"
#include "kernel/resize.hpp"
#include "kernel/resize_mirror_normalize.hpp"
#include "kernel/resize_crop_mirror.hpp"
#include "kernel/warp_affine.hpp"
#include "kernel/phase.hpp"
#include "kernel/slice.hpp"

#endif // HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP

==> rpp-6.3.3.tar.gz: rpp-rocm-6.3.3/src/modules/cpu/host_tensor_geometric_augmentations.hpp <==
/*
MIT License

Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

#ifndef HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP
#define HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP

#include "kernel/crop.hpp"
#include "kernel/crop_mirror_normalize.hpp"
#include "kernel/flip.hpp"
#include "kernel/remap.hpp"
#include "kernel/resize.hpp"
#include "kernel/resize_mirror_normalize.hpp"
#include "kernel/resize_crop_mirror.hpp"
#include "kernel/warp_affine.hpp"
#include "kernel/phase.hpp"
#include "kernel/slice.hpp"
#include "kernel/lens_correction.hpp"
#include "kernel/transpose.hpp"
#include "kernel/crop_and_patch.hpp"
#include "kernel/flip_voxel.hpp"

#endif // HOST_TENSOR_GEOMETRIC_AUGMENTATIONS_HPP
